heros.helper - heros 0.7.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# heros.helper

## Attributes

`log` |

## Functions

`object_name_from_keyexpr`(key_expr, ns_objects, realm) |
`full_classname`(o) | Return the fully qualified class name of an object.

## Module Contents

heros.helper.log

heros.helper.object_name_from_keyexpr(key_expr, ns_objects, realm, endpoint='.*')

heros.helper.full_classname(o)

  Return the fully qualified class name of an object.

  Parameters:

    o – object

  Returns:

    fully qualified module and class name